﻿(function () {
    'use strict';

    var getUrlParams = function () {
        var urlParams = {};
        var match,
            pl = /\+/g, // Regex for replacing addition symbol with a space
            search = /([^&=]+)=?([^&]*)/g,
            decode = function (s) { return decodeURIComponent(s.replace(pl, " ")); },
            query = window.location.search.substring(1);

        while (match = search.exec(query)) {
            urlParams[decode(match[1])] = decode(match[2]);
        }
        return urlParams;
    };

    var getAgencySystemModel = function() {

        var agencySystemService = kendo.data.Model.define({
            agencyID: "AgencyID", // the identifier of the model
            fields: {
                "AgencySystemID": { type: "number", editable: false},
                "AgencyID": { type: "number", editable: false },
                "Description": { type: "string" },
                "DatabaseTypeID": { type: "number" },
                "DataSource": { type: "string" },
                "InitalCatalog": { type: "string" },
                "UserID": { type: "string" },
                "Password": { type: "string" },
                "LastImportStartDateTime": { type: "date" },
                "LastImportEndDateTime": { type: "date" },
                "NextImportDateTime": { type: "date" },
                "UpToDateTime": { type: "date" },
                "ImportFrequency": { type: "number" },
                "ImportFrequencyUnitID": { type: "number" },
                "MaxImportWindow": { type: "number" },
                "IsActive": { type: "boolean" }
            }
        });

        return agencySystemService;
    };


    var updateAgencySystemInfo = function (agencyId, agencySystemModel) {
        var ds = new kendo.data.DataSource({
            transport: {
                read: {
                    type:"GET",
                    url: "/Administrator/GetAgencySystemInfo",
                    contentType: "application/json; charset=utf-8",
                    dataType: "json"
                },
                parameterMap: function (options, operation) {
                    switch (operation) {
                        case "read":
                            return options;
                            break;
                    }
                }
            },
            schema: {
                model: agencySystemModel
            },
            change: function () {
                var data = this.data();
                for (var i = 0; i < data.length; i++) {
                    var description = data[i].Description;
                }
            }
        });

        ds.read({ agencyID: agencyId });

    };



    window.Aries_Web.AgencyTreeView_Select = function (e) {
        var node = $(e.node);
        var dataItem = e.sender.dataItem(e.node);
        var agencyId;
        var agencySystemModel = getAgencySystemModel();

        if (!dataItem.hasChildren) {
            agencyId = node.data("agency-id");
            window.Aries_Web.setSelectedAgency(agencyId, node.text());

            updateAgencySystemInfo(agencyId, agencySystemModel);

            window.Aries_Web.selectedAgencyId = agencyId;
        }
        else {
            if (node.attr("data-expanded")) {
                window.treeView.collapse(node);
            }
            else {
                window.treeView.expand(node);
            }
            e.preventDefault();

            setTimeout(function () {
                $(":focus").blur();
            }, 0);
            return false;
        }
    };

    $(document).ready(function () {

        var selectedAgencyLi, treeView;
        var queryStringParams;
        var agencySystemModel;

        queryStringParams = getUrlParams();
        agencySystemModel = getAgencySystemModel();

        if ("agencyId" in queryStringParams) {
            selectedAgencyLi = $("#agencyTreeView li[data-agency-id=" + queryStringParams['agencyId'] + "]");
        } else {
            selectedAgencyLi = $("#agencyTreeView li[data-agency-id]:first");
        }
        treeView = $("#agencyTreeView").data("kendoTreeView");
        window.treeView = treeView;

        treeView.select(selectedAgencyLi);
        treeView.expand(selectedAgencyLi.parent());

        window.Aries_Web.setSelectedAgency(selectedAgencyLi.data("agencyId"), selectedAgencyLi.text());


        updateAgencySystemInfo(selectedAgencyLi.data("agency-id"), agencySystemModel);

        window.Aries_Web.selectedAgencyId = selectedAgencyLi.data("agency-id");

        

    });
})();